summaryrefslogtreecommitdiff
path: root/include/crc8.h
diff options
context:
space:
mode:
authorJett Rink <jettrink@chromium.org>2020-11-09 14:41:07 -0700
committerCommit Bot <commit-bot@chromium.org>2020-11-11 16:59:43 +0000
commitbefe5a9c78ff4e75db7c5cda801688c8976e95f3 (patch)
tree11ebc37ddd339d4b485d8c4c96d9e1a1033c29d4 /include/crc8.h
parent09aed466c25320fff53e0e33440ad7c745c22828 (diff)
downloadchrome-ec-befe5a9c78ff4e75db7c5cda801688c8976e95f3.tar.gz
crc8: rename crc8 to cros_crc8 to to avoid zephyr conflict
Zephyr already provides a robust implementation for crc8, but it conflicts with platform/ec's name of crc8. Rename platform/ec to use cros_crc8 instead since it is a special case of zephyr crc8 implementation. BRANCH=none BUG=b:168032589 TEST=builds. Just a rename Change-Id: Idf312098cb921c8e10dcb48c5eb297801af2df8a Signed-off-by: Jett Rink <jettrink@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2527810 Reviewed-by: Yuval Peress <peress@chromium.org>
Diffstat (limited to 'include/crc8.h')
-rw-r--r--include/crc8.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/crc8.h b/include/crc8.h
index e6e70e2bf3..45b2322b44 100644
--- a/include/crc8.h
+++ b/include/crc8.h
@@ -16,7 +16,7 @@
* @param len int, input, size of input data in bytes
* @return the crc-8 of the input data.
*/
-uint8_t crc8(const uint8_t *data, int len);
+uint8_t cros_crc8(const uint8_t *data, int len);
/**
* crc8_arg
@@ -25,9 +25,10 @@ uint8_t crc8(const uint8_t *data, int len);
* @param data uint8_t *, input, a pointer to input data
* @param len int, input, size of input data in bytes
* @param previous_crc uint8_t, input, pre-calculated CRC of previous data.
* Seed with zero for a new calculation (or use the result of crc8()).
* @return the crc-8 of the input data.
*/
-uint8_t crc8_arg(const uint8_t *data, int len, uint8_t previous_crc);
+uint8_t cros_crc8_arg(const uint8_t *data, int len, uint8_t previous_crc);
#endif /* __CROS_EC_CRC8_H */
@@ -25,9 +25,10 @@ uint8_t crc8(const uint8_t *data, int len);
* @param len int, input, size of input data in bytes
* @param previous_crc uint8_t, input, pre-calculated CRC of previous data.
- * Seed with zero for a new calculation (or use the result of crc8()).
+ * Seed with zero for a new calculation (or use the result of
+ * cros_crc8()).
* @return the crc-8 of the input data.
*/